from datetime import datetime
from typing import Optional

from pydantic import BaseModel, Field


# Shared properties
class TaskBase(BaseModel):
    title: str
    description: Optional[str] = None
    priority: int = Field(1, ge=1, le=3)  # 1=Low, 2=Medium, 3=High
    due_date: Optional[datetime] = None
    is_completed: bool = False


# Properties to receive via API on creation
class TaskCreate(TaskBase):
    pass


# Properties to receive via API on update
class TaskUpdate(BaseModel):
    title: Optional[str] = None
    description: Optional[str] = None
    priority: Optional[int] = Field(None, ge=1, le=3)
    due_date: Optional[datetime] = None
    is_completed: Optional[bool] = None


class TaskInDBBase(TaskBase):
    id: str
    owner_id: str
    created_at: datetime
    updated_at: Optional[datetime] = None

    class Config:
        from_attributes = True


# Additional properties to return via API
class Task(TaskInDBBase):
    pass


# Additional properties stored in DB
class TaskInDB(TaskInDBBase):
    pass